![CI](https://github.com/olgabiro/briefly/actions/workflows/build.yml/badge.svg)

A modern way to build beautiful PDF reports.

Built on top of [fpdf2](https://py-pdf.github.io/fpdf2/index.html).


**Briefly** is a Python library for building beautiful, modern PDF reports from scratch. It provides a clean, design-focused API for layout, styling and rendering.
